==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GeographicMapSeriesHostDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicMapSeriesHostDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicMapSeriesHostDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicMapSeriesHostDescriptionMetadata.a == null) {
                GeographicMapSeriesHostDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicMapSeriesHostDescriptionMetadata.c(GeographicMapSeriesHostDescriptionMetadata.a);
            }
            if (a.k(GeographicMapSeriesHostDescriptionMetadata.a)) {
                return;
            }
            a.ab(GeographicMapSeriesHostDescriptionMetadata.a);
        }
        static c(a) {
            SeriesDescriptionMetadata.c(a);
            a.item("VisibleFromScale", "Number:double");
            a.item("CoercionMethodsRef", "(w:CoercionMethods,wf:CoercionMethods)DataRef");
        }
        static d(a) {
            GeographicMapSeriesHostDescriptionMetadata.b(a);
            a.ac("GeographicMapSeriesHost", GeographicMapSeriesHostDescriptionMetadata.a);
        }
    }
    GeographicMapSeriesHostDescriptionMetadata.$t = markType(GeographicMapSeriesHostDescriptionMetadata, 'GeographicMapSeriesHostDescriptionMetadata');
    GeographicMapSeriesHostDescriptionMetadata.a = null;
    return GeographicMapSeriesHostDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GeographicMapSeriesHostDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicMapSeriesHostDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicMapSeriesHostDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicMapSeriesHostDescriptionMetadata.a == null) {
                GeographicMapSeriesHostDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicMapSeriesHostDescriptionMetadata.c(GeographicMapSeriesHostDescriptionMetadata.a);
            }
            if (a.k(GeographicMapSeriesHostDescriptionMetadata.a)) {
                return;
            }
            a.ac(GeographicMapSeriesHostDescriptionMetadata.a);
        }
        static c(a) {
            SeriesDescriptionMetadata.c(a);
            a.item("VisibleFromScale", "Number:double");
            a.item("CoercionMethodsRef", "(w:CoercionMethods,wf:CoercionMethods)DataRef");
        }
        static d(a) {
            GeographicMapSeriesHostDescriptionMetadata.b(a);
            a.ad("GeographicMapSeriesHost", GeographicMapSeriesHostDescriptionMetadata.a);
        }
    }
    GeographicMapSeriesHostDescriptionMetadata.$t = markType(GeographicMapSeriesHostDescriptionMetadata, 'GeographicMapSeriesHostDescriptionMetadata');
    GeographicMapSeriesHostDescriptionMetadata.a = null;
    return GeographicMapSeriesHostDescriptionMetadata;
})();
